@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: project-template
 version: 0.2.0
-id: project-template-0.2.0-5f22bf7fb56ba29cfb440dc2c2b0a984
-key: proje_LityNPX97Yv0g6ifoB81GC
+id: project-template-0.2.0-ca00d09bfef881cf1b16afc25e35f9bd
+key: proje_E7Yo5QkY5SqIDTexdL4Jl8
 license: BSD3
 maintainer: michael@fpcomplete.com
 homepage: https://github.com/fpco/haskell-ide
@@ -19,13 +19,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
-hs-libraries: HSproject-template-0.2.0-LityNPX97Yv0g6ifoB81GC
+hs-libraries: HSproject-template-0.2.0-E7Yo5QkY5SqIDTexdL4Jl8
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
-    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
